==> nextcloud-27.1.4.tgz: nextcloud/apps/weather_status/l10n/es_EC.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Dirección desconocida",
    "No result." : "Sin resultados.",
    "Malformed JSON data." : "Datos JSON mal formados.",
    "Error" : "Error",
    "Weather status" : "Estado del clima",
    "Weather status in your dashboard" : "Estado del clima en tu tablero",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Estado del clima integrado en la aplicación Tablero.\n          La posición del usuario puede determinarse automáticamente o definirse manualmente. Luego se muestra un pronóstico de 6 horas.\n          Este estado también puede integrarse en otros lugares, como la aplicación Calendario.",
    "Detect location" : "Detectar ubicación",
    "Set custom address" : "Establecer dirección personalizada",
    "Favorites" : "Favoritos",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} cielo despejado más tarde hoy",
    "{temperature} {unit} clear sky" : "{temperature} {unit} cielo despejado",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} nublado más tarde hoy",
    "{temperature} {unit} cloudy" : "{temperature} {unit} nublado",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} clima bueno más tarde hoy",
    "{temperature} {unit} fair weather" : "{temperature} {unit} clima bueno",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} parcialmente nublado más tarde hoy",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} parcialmente nublado",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} niebla más tarde hoy",
    "{temperature} {unit} foggy" : "{temperature} {unit} niebla",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} lluvia ligera más tarde hoy",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} lluvia ligera",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} lluvia más tarde hoy",
    "{temperature} {unit} rainfall" : "{temperature} {unit} lluvia",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} lluvia intensa más tarde hoy",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} lluvia intensa",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} lluvia intermitente más tarde hoy",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} lluvia intermitente",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} lluvia ligera intermitente más tarde hoy",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} lluvia ligera intermitente",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} lluvia intensa intermitente más tarde hoy",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} lluvia intensa intermitente",
    "More weather for {adr}" : "Más información sobre el clima para {adr}",
    "Loading weather" : "Cargando clima",
    "Remove from favorites" : "Eliminar de favoritos",
    "Add as favorite" : "Agregar como favorito",
    "You are not logged in." : "No has iniciado sesión.",
    "There was an error getting the weather status information." : "Hubo un error al obtener la información del estado del clima.",
    "No weather information found" : "No se encontró información del clima",
    "Location not found" : "Ubicación no encontrada",
    "There was an error setting the location address." : "Hubo un error al establecer la dirección de ubicación.",
    "There was an error setting the location." : "Hubo un error al establecer la ubicación.",
    "There was an error saving the mode." : "Hubo un error al guardar el modo.",
    "There was an error using personal address." : "Hubo un error al usar la dirección personal.",
    "Set location for weather" : "Establecer ubicación para el clima"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-28.0.3.tgz: nextcloud/apps/weather_status/l10n/es_EC.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Dirección desconocida",
    "No result." : "Sin resultados.",
    "Malformed JSON data." : "Datos JSON mal formados.",
    "Error" : "Error",
    "Weather status" : "Estado del clima",
    "Weather status in your dashboard" : "Estado del clima en tu tablero",
    "Detect location" : "Detectar ubicación",
    "Set custom address" : "Establecer dirección personalizada",
    "Favorites" : "Favoritos",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} cielo despejado más tarde hoy",
    "{temperature} {unit} clear sky" : "{temperature} {unit} cielo despejado",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} nublado más tarde hoy",
    "{temperature} {unit} cloudy" : "{temperature} {unit} nublado",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} clima bueno más tarde hoy",
    "{temperature} {unit} fair weather" : "{temperature} {unit} clima bueno",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} parcialmente nublado más tarde hoy",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} parcialmente nublado",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} niebla más tarde hoy",
    "{temperature} {unit} foggy" : "{temperature} {unit} niebla",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} lluvia ligera más tarde hoy",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} lluvia ligera",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} lluvia más tarde hoy",
    "{temperature} {unit} rainfall" : "{temperature} {unit} lluvia",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} lluvia intensa más tarde hoy",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} lluvia intensa",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} lluvia intermitente más tarde hoy",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} lluvia intermitente",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} lluvia ligera intermitente más tarde hoy",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} lluvia ligera intermitente",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} lluvia intensa intermitente más tarde hoy",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} lluvia intensa intermitente",
    "More weather for {adr}" : "Más información sobre el clima para {adr}",
    "Loading weather" : "Cargando clima",
    "Remove from favorites" : "Eliminar de favoritos",
    "Add as favorite" : "Agregar como favorito",
    "You are not logged in." : "No has iniciado sesión.",
    "There was an error getting the weather status information." : "Hubo un error al obtener la información del estado del clima.",
    "No weather information found" : "No se encontró información del clima",
    "Location not found" : "Ubicación no encontrada",
    "There was an error setting the location address." : "Hubo un error al establecer la dirección de ubicación.",
    "There was an error setting the location." : "Hubo un error al establecer la ubicación.",
    "There was an error saving the mode." : "Hubo un error al guardar el modo.",
    "There was an error using personal address." : "Hubo un error al usar la dirección personal.",
    "Set location for weather" : "Establecer ubicación para el clima",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Estado del clima integrado en la aplicación Tablero.\n          La posición del usuario puede determinarse automáticamente o definirse manualmente. Luego se muestra un pronóstico de 6 horas.\n          Este estado también puede integrarse en otros lugares, como la aplicación Calendario."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
